@@ -164,10 +164,11 @@ def heatmap(x, y, value, figuresize=(10,10), fontsize=20,colour_from_to=(15,235)
 
     return fig
 
-def correlation_heatmap(df,columns,minimum_size=-1,maximum_size=1,**kwargs):
+def correlation_heatmap(df,method='pearson',columns,minimum_size=-1,maximum_size=1,**kwargs):
     '''
     A function to just do a correlation heatmap between the specified columns
     :param df: The data frame object
+    :param method: The correlation type. 'pearson', 'kendall', 'spearman' or callable Method of correlation
     :param columns: A list of column names to do a correlation between
     :param minimum_size: float. Where you want to colour scale to start from. i.e. the minimum value. Default = -1
     :param maximum_size: float. Where you want to colour scale to end. i.e. the maximum value. Default = +1
@@ -187,7 +188,7 @@ def correlation_heatmap(df,columns,minimum_size=-1,maximum_size=1,**kwargs):
     data = df[columns].copy()
     
     # get a correlation matrix between all columns
-    corr = data.corr()
+    corr = data.corr(method)
     
     # convert the dataframe by unpivotting so that the first 2 columns are the pair of names and the 3rd column their correlation
     corr = pd.melt(corr.reset_index(), id_vars='index')
